@@ -7,9 +7,10 @@ pub mod staticlib_header;
 pub type CIdent = String;
 
 /// A Type in the C language.
-#[derive(Debug, Clone)]
+#[derive(Debug, Clone, Default)]
 pub enum CType {
     /// C `void` type.
+    #[default]
     Void,
     /// A pointer to some other type.
     PointerTo {
@@ -214,12 +215,6 @@ impl CType {
     }
 }
 
-impl Default for CType {
-    fn default() -> CType {
-        CType::Void
-    }
-}
-
 /// A statement in the C programming language. This may not be exact to what an
 /// AST would look like or what the C standard says about the C language, it's
 /// simply a structed way to organize data for generating C code.
