@@ -105,9 +105,9 @@ impl Run {
 
         let _guard = handle.enter();
         let (store, _) = self.store.get_store()?;
-        let runtime =
-            self.wasi
-                .prepare_runtime(store.engine().clone(), &self.env, handle.clone())?;
+        let runtime = self
+            .wasi
+            .prepare_runtime(store.engine().clone(), &self.env, runtime)?;
 
         // This is a slow operation, so let's temporarily wrap the runtime with
         // something that displays progress
@@ -842,9 +842,7 @@ impl wasmer_wasix::runtime::package_loader::PackageLoader for MonitoringPackageL
         let pkg_id = summary.package_id();
         self.progress.set_message(format!("Downloading {pkg_id}"));
 
-        let result = self.inner.load(summary).await;
-
-        result
+        self.inner.load(summary).await
     }
 
     async fn load_package_tree(
